package Locale::CLDR::Locales::Ca::Any;

# This file auto generated
#	on Fri 10 Jul  3:14:57 pm GMT

use version;

our $VERSION = version->declare('v0.27.2');

use v5.10;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Ca');

no Moose;
__PACKAGE__->meta->make_immutable;
