=head1

Locale::CLDR::Locales::Ca::Any::It - Package for language Catalan

=cut

package Locale::CLDR::Locales::Ca::Any::It;
# This file auto generated from Data\common\main\ca_IT.xml
#	on Fri 10 Jul  3:14:57 pm GMT
# XML file generated 2014-07-23 16:10:33 -0500 (Wed, 23 Jul 2014)

use version;

our $VERSION = version->declare('v0.27.2');

use v5.10;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

extends('Locale::CLDR::Locales::Ca::Any');
no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
